PyTorch implementation of HighRes3DNet from [Li et al., 2017,
*On the Compactness, Efficiency, and Representation of
3D Convolutional Networks: Brain Parcellation as a Pretext Task*][li].

A 2D version (HighRes2DNet) is also available.

[li]: https://arxiv.org/pdf/1707.01992.pdf
